@@ -49,4 +49,6 @@ class Input:
 
     @staticmethod
     def is_free_user():
+        if os.getenv('user_plan'.upper()) == 'IS_OWNER':
+            return False
         return os.getenv('user_plan'.upper()) == 'FREE'
